proc int {value} {
   set a [expr ceil($value)]
   set point [expr [string first . $a]-1]
   set value [string range $a 0 $point]
}


# =======================================
# === Initialisation of the variables.
# === Initialisation des variables.
# =======================================

#--- definition of global variables (arrays)
#--- definition des variables globales (arrays)
global num        # index for devices
global caption    # texts of captions
global zone       # window name of usefull screen parts
global info_image # some infos on the current image
global geom       # geomety size of widgets

#--- selection of langage
#--- selection du langage
source langage.tcl

#--- definition of captions
#--- definition des legendes
if {[string compare $langage english] ==0 } {
   set caption(main_title) "LX 200 keypad"
   set caption(telok) "tel linked"
   set caption(telpb) "tel not found"
}
if {[string compare $langage french] ==0 } {
   set caption(main_title) "Raquette LX 200"
   set caption(exit) "Quitter"
   set caption(telok) "tel trouve"
   set caption(telpb) "tel non trouve"
}

#--- definition of colors
#--- definition des couleurs
set color(back) #123456
set color(backpad) #123456
set color(backkey) #808080
set color(textkey) #FFFFFF
set color(backdisp) #ED4E59
set color(textdisp) #000000

#--- definition des geometries
#--- definition of geometry
set zoom 2
set geom(larg) [int [expr 300*$zoom]]
set geom(long) [int [expr 610*$zoom+40]]
set geom(fontsize25) [int [expr (25*$zoom)]]
set geom(fontsize20) [int [expr (20*$zoom)]]
set geom(fontsize16) [int [expr (16*$zoom)]]
set geom(fontsize14) [int [expr (14*$zoom)]]
set geom(fontsize10) [int [expr (10*$zoom)]]
set geom(10pixels) [int [expr (10*$zoom)]]
set geom(20pixels) [int [expr (20*$zoom)]]
set geom(larg2) [int [expr (85*$zoom)]]
set geom(haut2) [int [expr (65*$zoom)]]
set geom(haut) [int [expr (70*$zoom)]]
set geom(linewidth0) [int [expr (3*$zoom)]]
set geom(linewidth) [int [expr $geom(linewidth0)+1]]
set geom(lightx1) [int [expr (10*$zoom)]]
set geom(lighty1) [int [expr (30*$zoom)]]
set geom(lightx2) [int [expr (20*$zoom)]]
set geom(lighty2) [int [expr (40*$zoom)]]
if {$geom(linewidth0)<=2} {set geom(textthick) ""} else {set geom(textthick) "bold"} 

# =========================================
# === Setting the graphic interface.
# === Met en place l'interface graphique.
# =========================================


#--- hide the window root
#--- cahce la fenetre racine
wm withdraw .

#--- create the toplevel window .test
#--- cree la fenetre .test de niveau le plus haut
toplevel .lx200 -class Toplevel -bg $color(backpad)
wm geometry .lx200 $geom(larg)x$geom(long)+0+0
wm resizable .lx200 0 0
wm title .lx200 $caption(main_title)

#--- create the title
#--- cree le titre
label .lx200.meade \
   -font [list {Arial} $geom(fontsize25) $geom(textthick) ] -text Meade \
   -borderwidth 0 -relief flat -bg $color(backpad) \
   -fg $color(textkey)
pack .lx200.meade \
   -in .lx200 -fill x -side top

#--- create the display
#--- cree l'ecran
listbox .lx200.display \
   -font [list {Courier} $geom(fontsize16) $geom(textthick) ] -height 2 -width 16\
   -borderwidth 2 -relief sunken -bg $color(backdisp) \
   -fg $color(textdisp) -selectbackground $color(backdisp) \
   -selectborderwidth 0 -selectforeground $color(textdisp)
pack .lx200.display \
   -in .lx200 -side top -pady $geom(10pixels)
set zone(disp) .lx200.display
.lx200.display insert end ">TELESCOPE"
.lx200.display insert end " OBJECT LIBRARY "

#--- create a dummy space
#--- cree un espace inutile
frame .lx200.dum1 \
   -height $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.dum1 \
   -in .lx200 -side top -fill x

#--- create a frame for the function buttons
#--- cree un espace pour les boutons de fonction
frame .lx200.func \
   -height 70 \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.func \
   -in .lx200 -side top -fill x

# --- create the button 'enter'

frame .lx200.func.enter \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.func.enter \
   -in .lx200.func -side left
# --- button-design
canvas .lx200.func.enter.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.func.enter.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth) $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth) \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.func.enter.canv1 \
   -in .lx200.func.enter -expand 1
# --- write the label
label .lx200.func.enter.canv1.lab \
   -font [list {Arial} $geom(fontsize14) $geom(textthick) ] -text ENTER \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.func.enter.canv1.lab \
   -in .lx200.func.enter.canv1 -x [int [expr (11*$zoom)]] -y [int [expr (22*$zoom)]]

# --- create the button 'go to'
frame .lx200.func.goto \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.func.goto \
   -in .lx200.func -side right
# --- button-design
canvas .lx200.func.goto.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.func.goto.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.func.goto.canv1 \
   -in .lx200.func.goto -expand 1
# --- write the label
label .lx200.func.goto.canv1.lab \
   -font [list {Arial} $geom(fontsize14) $geom(textthick) ] -text "GO TO" \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.func.goto.canv1.lab \
   -in .lx200.func.goto.canv1 -x [int [expr (13*$zoom)]] -y [int [expr (22*$zoom)]]

# --- create the button 'mode'
frame .lx200.func.mode \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.func.mode \
   -in .lx200.func -side top
# --- button-design
canvas .lx200.func.mode.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.func.mode.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.func.mode.canv1 \
   -in .lx200.func.mode -expand 1
# --- write the label
label .lx200.func.mode.canv1.lab \
   -font [list {Arial} $geom(fontsize14) $geom(textthick) ] -text MODE \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.func.mode.canv1.lab \
   -in .lx200.func.mode.canv1 -x [int [expr (13*$zoom)]] -y [int [expr (22*$zoom)]]

#--- create a frame for the cardinal buttons
#--- cree un espace pour les boutons cardinaux
frame .lx200.card \
   -height 150 \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.card \
   -in .lx200 -side top -fill x

#--- create a dummy space
#--- cree un espace inutile
frame .lx200.card.dumw \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.card.dumw \
   -in .lx200.card -side left -fill y

# --- create the button 'W'
set geom(larg2) $geom(haut2)
frame .lx200.card.w \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.card.w \
   -in .lx200.card -side left
# --- button-design
canvas .lx200.card.w.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.card.w.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.card.w.canv1 \
   -in .lx200.card.w -expand 1
# --- write the label
label .lx200.card.w.canv1.lab \
   -font [list {Arial} $geom(fontsize25) $geom(textthick) ] -text W \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.card.w.canv1.lab \
   -in .lx200.card.w.canv1 -x [int [expr (17*$zoom)]] -y [int [expr (15*$zoom)]]
set zone(w) .lx200.card.w.canv1

#--- create a dummy space
#--- cree un espace inutile
frame .lx200.card.dume \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.card.dume \
   -in .lx200.card -side right -fill y

# --- create the button 'E'
frame .lx200.card.e \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad) 
pack .lx200.card.e \
   -in .lx200.card -side right
# --- button-design
canvas .lx200.card.e.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.card.e.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.card.e.canv1 \
   -in .lx200.card.e -expand 1
# --- write the label
label .lx200.card.e.canv1.lab \
   -font [list {Arial} $geom(fontsize25) $geom(textthick) ] -text E \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.card.e.canv1.lab \
   -in .lx200.card.e.canv1 -x [int [expr (22*$zoom)]] -y [int [expr (15*$zoom)]]
set zone(e) .lx200.card.e.canv1

# --- create the button 'N'
frame .lx200.card.n \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.card.n \
   -in .lx200.card -side top
# --- button-design
canvas .lx200.card.n.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.card.n.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.card.n.canv1 \
   -in .lx200.card.n -expand 1
# --- write the label
label .lx200.card.n.canv1.lab \
   -font [list {Arial} $geom(fontsize25) $geom(textthick) ] -text N \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.card.n.canv1.lab \
   -in .lx200.card.n.canv1 -x [int [expr (22*$zoom)]] -y [int [expr (15*$zoom)]]
set zone(n) .lx200.card.n.canv1

# --- create the button 'S'
frame .lx200.card.s \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.card.s \
   -in .lx200.card -side top
# --- button-design
canvas .lx200.card.s.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.card.s.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.card.s.canv1 \
   -in .lx200.card.s -expand 1
# --- write the label
label .lx200.card.s.canv1.lab \
   -font [list {Arial} $geom(fontsize25) $geom(textthick) ] -text S \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.card.s.canv1.lab \
   -in .lx200.card.s.canv1 -x [int [expr (22*$zoom)]] -y [int [expr (15*$zoom)]]
set zone(s) .lx200.card.s.canv1

#--- create a frame for the 789 buttons
#--- cree un espace pour les boutons 789
frame .lx200.789 \
   -height 150 \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.789 \
   -in .lx200 -side top -fill x

# --- create the light 'slew'
frame .lx200.789.slew \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg #00FF00 
#$color(backpad)
pack .lx200.789.slew \
   -in .lx200.789 -side left -fill y
canvas .lx200.789.slew.canv1 \
   -width $geom(20pixels) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backpad) \
   -highlightbackground $color(backpad)
.lx200.789.slew.canv1 create oval $geom(lightx1) $geom(lighty1) $geom(lightx2) $geom(lighty2) \
   -fill #FF0000
pack .lx200.789.slew.canv1 \
   -in .lx200.789.slew -expand 1
set zone(slew) .lx200.789.slew.canv1

# --- create the button '7'
frame .lx200.789.7 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.789.7 \
   -in .lx200.789 -side left
# --- button-design
canvas .lx200.789.7.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.789.7.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.789.7.canv1 \
   -in .lx200.789.7 -expand 1
# --- write the label
label .lx200.789.7.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 7 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.789.7.canv1.lab1 \
   -in .lx200.789.7.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.789.7.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text SLEW \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.789.7.canv1.lab2 \
   -in .lx200.789.7.canv1 -x [int [expr (13*$zoom)]] -y [int [expr (10*$zoom)]]
set zone(7) .lx200.789.7.canv1

# --- create a dummy frame
frame .lx200.789.dume \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.789.dume \
   -in .lx200.789 -side right -fill y

# --- create the button '9'
frame .lx200.789.9 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.789.9 \
   -in .lx200.789 -side right
# --- button-design
canvas .lx200.789.9.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.789.9.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.789.9.canv1 \
   -in .lx200.789.9 -expand 1
# --- write the label
label .lx200.789.9.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 9 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.789.9.canv1.lab1 \
   -in .lx200.789.9.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.789.9.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text M \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.789.9.canv1.lab2 \
   -in .lx200.789.9.canv1 -x [int [expr (28*$zoom)]] -y [int [expr (10*$zoom)]]

# --- create the button '8'
frame .lx200.789.8 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.789.8 \
   -in .lx200.789 -side top
# --- button-design
canvas .lx200.789.8.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.789.8.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.789.8.canv1 \
   -in .lx200.789.8 -expand 1
# --- write the label
label .lx200.789.8.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 8 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.789.8.canv1.lab1 \
   -in .lx200.789.8.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.789.8.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text RET \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.789.8.canv1.lab2 \
   -in .lx200.789.8.canv1 -x [int [expr (20*$zoom)]] -y [int [expr (10*$zoom)]]

#--- create a frame for the 456 buttons
#--- cree un espace pour les boutons 456
frame .lx200.456 \
   -height 150 \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.456 \
   -in .lx200 -side top -fill x

# --- create the light 'find'
frame .lx200.456.find \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg #FF0000 
#$color(backpad)
pack .lx200.456.find \
   -in .lx200.456 -side left -fill y
canvas .lx200.456.find.canv1 \
   -width $geom(20pixels) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backpad) \
   -highlightbackground $color(backpad)
.lx200.456.find.canv1 create oval $geom(lightx1) $geom(lighty1) $geom(lightx2) $geom(lighty2) \
   -fill #000000
pack .lx200.456.find.canv1 \
   -in .lx200.456.find -expand 1
set zone(find) .lx200.456.find.canv1

# --- create the button '4'
frame .lx200.456.4 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.456.4 \
   -in .lx200.456 -side left
# --- button-design
canvas .lx200.456.4.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.456.4.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.456.4.canv1 \
   -in .lx200.456.4 -expand 1

# --- write the label
label .lx200.456.4.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 4 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.456.4.canv1.lab1 \
   -in .lx200.456.4.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.456.4.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text FIND \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.456.4.canv1.lab2 \
   -in .lx200.456.4.canv1 -x [int [expr (18*$zoom)]] -y [int [expr (10*$zoom)]]
set zone(4) .lx200.456.4.canv1

# --- create a dummy frame
frame .lx200.456.dume \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.456.dume \
   -in .lx200.456 -side right -fill y

# --- create the button '6'
frame .lx200.456.6 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.456.6 \
   -in .lx200.456 -side right
# --- button-design
canvas .lx200.456.6.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.456.6.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.456.6.canv1 \
   -in .lx200.456.6 -expand 1
# --- write the label
label .lx200.456.6.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 6 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.456.6.canv1.lab1 \
   -in .lx200.456.6.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.456.6.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text STAR \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.456.6.canv1.lab2 \
   -in .lx200.456.6.canv1 -x [int [expr (16*$zoom)]] -y [int [expr (10*$zoom)]]

# --- create the button '5'
frame .lx200.456.5 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.456.5 \
   -in .lx200.456 -side top
# --- button-design
canvas .lx200.456.5.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.456.5.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.456.5.canv1 \
   -in .lx200.456.5 -expand 1
# --- write the label
label .lx200.456.5.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 5 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.456.5.canv1.lab1 \
   -in .lx200.456.5.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.456.5.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text FOCUS \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.456.5.canv1.lab2 \
   -in .lx200.456.5.canv1 -x [int [expr (10*$zoom)]] -y [int [expr (10*$zoom)]]

#--- create a frame for the 123 buttons
#--- cree un espace pour les boutons 123
frame .lx200.123 \
   -height 150 \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.123 \
   -in .lx200 -side top -fill x

# --- create the light 'cntr'
frame .lx200.123.cntr \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.123.cntr \
   -in .lx200.123 -side left -fill y
canvas .lx200.123.cntr.canv1 \
   -width $geom(20pixels) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backpad) \
   -highlightbackground $color(backpad)
.lx200.123.cntr.canv1 create oval $geom(lightx1) $geom(lighty1) $geom(lightx2) $geom(lighty2) \
   -fill #000000
pack .lx200.123.cntr.canv1 \
   -in .lx200.123.cntr -expand 1
set zone(cntr) .lx200.123.cntr.canv1

# --- create the button '1'
set larg2 65
set haut2 65
frame .lx200.123.1 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.123.1 \
   -in .lx200.123 -side left
# --- button-design
canvas .lx200.123.1.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.123.1.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.123.1.canv1 \
   -in .lx200.123.1 -expand 1
# --- write the label
label .lx200.123.1.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 1 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.123.1.canv1.lab1 \
   -in .lx200.123.1.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.123.1.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text CNTR \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.123.1.canv1.lab2 \
   -in .lx200.123.1.canv1 -x [int [expr (16*$zoom)]] -y [int [expr (10*$zoom)]]
set zone(1) .lx200.123.1.canv1

# --- create a dummy frame
frame .lx200.123.dume \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.123.dume \
   -in .lx200.123 -side right -fill y

# --- create the button '3'
frame .lx200.123.3 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.123.3 \
   -in .lx200.123 -side right
# --- button-design
canvas .lx200.123.3.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.123.3.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.123.3.canv1 \
   -in .lx200.123.3 -expand 1
# --- write the label
label .lx200.123.3.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 3 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.123.3.canv1.lab1 \
   -in .lx200.123.3.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.123.3.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text CNGC \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.123.3.canv1.lab2 \
   -in .lx200.123.3.canv1 -x [int [expr (13*$zoom)]] -y [int [expr (10*$zoom)]]

# --- create the button '2'
frame .lx200.123.2 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.123.2 \
   -in .lx200.123 -side top
# --- button-design
canvas .lx200.123.2.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.123.2.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.123.2.canv1 \
   -in .lx200.123.2 -expand 1
# --- write the label
label .lx200.123.2.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 2 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.123.2.canv1.lab1 \
   -in .lx200.123.2.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.123.2.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text MAP \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.123.2.canv1.lab2 \
   -in .lx200.123.2.canv1 -x [int [expr (19*$zoom)]] -y [int [expr (10*$zoom)]]

#--- create a frame for the 000 buttons
#--- cree un espace pour les boutons 000
frame .lx200.000 \
   -height 150 \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.000 \
   -in .lx200 -side top -fill x

# --- create the light 'guide'
frame .lx200.000.guide \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.000.guide \
   -in .lx200.000 -side left -fill y
canvas .lx200.000.guide.canv1 \
   -width $geom(20pixels) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backpad) \
   -highlightbackground $color(backpad)
.lx200.000.guide.canv1 create oval $geom(lightx1) $geom(lighty1) $geom(lightx2) $geom(lighty2) \
   -fill #000000
pack .lx200.000.guide.canv1 \
   -in .lx200.000.guide -expand 1
set zone(guide) .lx200.000.guide.canv1

# --- create the button '0'
set larg2 65
set haut2 65
frame .lx200.000.0 \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.000.0 \
   -in .lx200.000 -side left
# --- button-design
canvas .lx200.000.0.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.000.0.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.000.0.canv1 \
   -in .lx200.000.0 -expand 1
# --- write the label
label .lx200.000.0.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text 0 \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.000.0.canv1.lab1 \
   -in .lx200.000.0.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.000.0.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text GUIDE \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.000.0.canv1.lab2 \
   -in .lx200.000.0.canv1 -x [int [expr (13*$zoom)]] -y [int [expr (10*$zoom)]]
set zone(0) .lx200.000.0.canv1

# --- create a dummy frame
frame .lx200.000.dume \
   -width $geom(20pixels) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.000.dume \
   -in .lx200.000 -side right -fill y

# --- create the button 'next'
frame .lx200.000.next \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.000.next \
   -in .lx200.000 -side right
# --- button-design
canvas .lx200.000.next.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.000.next.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth)
pack .lx200.000.next.canv1 \
   -in .lx200.000.next -expand 1
# --- write the label
label .lx200.000.next.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text " " \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.000.next.canv1.lab1 \
   -in .lx200.000.next.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.000.next.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text NEXT \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.000.next.canv1.lab2 \
   -in .lx200.000.next.canv1 -x [int [expr (16*$zoom)]] -y [int [expr (10*$zoom)]]

# --- create the button 'prev'
frame .lx200.000.prev \
   -width $geom(larg2) \
   -borderwidth 0 -relief flat -bg $color(backpad)
pack .lx200.000.prev \
   -in .lx200.000 -side top
# --- button-design
canvas .lx200.000.prev.canv1 \
   -width $geom(larg2) -height $geom(haut2) \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -highlightbackground $color(backpad)
.lx200.000.prev.canv1 create line $geom(linewidth) $geom(linewidth) $geom(linewidth)  $geom(haut2) $geom(larg2) $geom(haut2) $geom(larg2) $geom(linewidth) $geom(linewidth) $geom(linewidth)  \
   -fill $color(textkey) -width $geom(linewidth0)
pack .lx200.000.prev.canv1 \
   -in .lx200.000.prev -expand 1
# --- write the label
label .lx200.000.prev.canv1.lab1 \
   -font [list {Arial} $geom(fontsize20) $geom(textthick) ] -text " " \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.000.prev.canv1.lab1 \
   -in .lx200.000.prev.canv1 -x [int [expr (25*$zoom)]] -y [int [expr (28*$zoom)]]
# --- write the label
label .lx200.000.prev.canv1.lab2 \
   -font [list {Arial} $geom(fontsize10) $geom(textthick) ] -text PREV \
   -borderwidth 0 -relief flat -bg $color(backkey) \
   -fg $color(textkey)
place .lx200.000.prev.canv1.lab2 \
   -in .lx200.000.prev.canv1 -x [int [expr (15*$zoom)]] -y [int [expr (10*$zoom)]]


# =========================================
# === Setting the binding.
# === Met en place les liaisons.
# =========================================

#--- destroy the toplevel window with the upper right cross
#--- detruit la fenetre principale avec la croix en haut a droite
bind .lx200 <Destroy> { 
   if {[string compare $num(tel1) 0] != 0 } {
      tel::delete $num(tel1)
   }
   destroy .lx200
   exit 
}

# ========================================
# === Setting the astronomical devices ===
# ========================================

#--- declare a new telescope
set num(tel1) [tel::create lx200 com2]
$zone(disp) delete 0 end
if {[string first Could $num(tel1)] == -1 } {
   $zone(disp) insert end "$caption(telok) \#$num(tel1)"
} else {
   $zone(disp) insert end " $caption(telpb)"
   set num(tel1) 0
}

# --- refreach the coordinates on the display
bind $zone(disp) <1> {
   if {[string compare $num(tel1) 0] != 0 } {
      set ligne [tel$num(tel1) coord]
      $zone(disp) delete 0 end
      $zone(disp) insert end [lindex $ligne 0]
      $zone(disp) insert end [lindex $ligne 1]   
   }
}

if {[string compare $num(tel1) 0] != 0 } {
   # --- cardinal moves
   bind $zone(e) <ButtonPress-1> { tel$num(tel1) move e }
   bind $zone(e).lab <ButtonPress-1> { tel$num(tel1) move e }
   bind $zone(e) <ButtonRelease-1> { tel$num(tel1) stop e }
   bind $zone(e).lab <ButtonRelease-1> { tel$num(tel1) stop e }
   bind $zone(w) <ButtonPress-1> { tel$num(tel1) move w }
   bind $zone(w).lab <ButtonPress-1> { tel$num(tel1) move w }
   bind $zone(w) <ButtonRelease-1> { tel$num(tel1) stop w }
   bind $zone(w).lab <ButtonRelease-1> { tel$num(tel1) stop w }
   bind $zone(s) <ButtonPress-1> { tel$num(tel1) move s }
   bind $zone(s).lab <ButtonPress-1> { tel$num(tel1) move s }
   bind $zone(s) <ButtonRelease-1> { tel$num(tel1) stop s }
   bind $zone(s).lab <ButtonRelease-1> { tel$num(tel1) stop s }
   bind $zone(n) <ButtonPress-1> { move_n tel$num(tel1) }
   bind $zone(n).lab <ButtonPress-1> { move_n tel$num(tel1) }
   bind $zone(n) <ButtonRelease-1> { tel$num(tel1) stop n }
   bind $zone(n).lab <ButtonRelease-1> { tel$num(tel1) stop n }
   # --- set speeds
   bind $zone(7) <ButtonPress-1> {set_slew}
   bind $zone(7).lab1 <ButtonPress-1> {set_slew}
   bind $zone(7).lab2 <ButtonPress-1> {set_slew}
   bind $zone(4) <ButtonPress-1> {set_find}
   bind $zone(4).lab1 <ButtonPress-1> {set_find}
   bind $zone(4).lab2 <ButtonPress-1> {set_find}
   bind $zone(1) <ButtonPress-1> {set_cntr}
   bind $zone(1).lab1 <ButtonPress-1> {set_cntr}
   bind $zone(1).lab2 <ButtonPress-1> {set_cntr}
   bind $zone(0) <ButtonPress-1> {set_guide}
   bind $zone(0).lab1 <ButtonPress-1> {set_guide}
   bind $zone(0).lab2 <ButtonPress-1> {set_guide}
}


# ===================================
# === It is the end of the script ===
# ===================================


proc move_n { telescope } {
   $telescope move n 
}

proc set_slew {} {
   global num zone
   tel$num(tel1) speed slew 
   $zone(slew) itemconfigure 1 -fill #FF0000
   $zone(find) itemconfigure 1 -fill #000000
   $zone(cntr) itemconfigure 1 -fill #000000
   $zone(guide) itemconfigure 1 -fill #000000
}

proc set_find {} {
   global num zone
   tel$num(tel1) speed find 
   $zone(slew) itemconfigure 1 -fill #000000
   $zone(find) itemconfigure 1 -fill #FF0000
   $zone(cntr) itemconfigure 1 -fill #000000
   $zone(guide) itemconfigure 1 -fill #000000
}

proc set_cntr {} {
   global num zone
   tel$num(tel1) speed center 
   $zone(slew) itemconfigure 1 -fill #000000
   $zone(find) itemconfigure 1 -fill #000000
   $zone(cntr) itemconfigure 1 -fill #FF0000
   $zone(guide) itemconfigure 1 -fill #000000
}

proc set_guide {} {
   global num zone
   tel$num(tel1) speed guide 
   $zone(slew) itemconfigure 1 -fill #000000
   $zone(find) itemconfigure 1 -fill #000000
   $zone(cntr) itemconfigure 1 -fill #000000
   $zone(guide) itemconfigure 1 -fill #FF0000
}

